==> mysql-connector-net-8.0.19-src.zip: MySQL.Data/tests/MySqlX.Data.Tests/CrudTests/DocBufferingTests.cs <==
// Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

using MySqlX.XDevAPI;
using MySqlX.XDevAPI.Common;
using Xunit;

namespace MySqlX.Data.Tests.CrudTests
{
  public class DocBufferingTests : BaseTest
  {
    [Fact]
    public void SmartBuffering()
    {
      Collection test = CreateCollection("test");
      Collection test2 = CreateCollection("test2");

      var docs = new[]
      {
        new {  _id = 1, title = "Book 1", pages = 20 },
        new {  _id = 2, title = "Book 2", pages = 30 },
        new {  _id = 3, title = "Book 3", pages = 40 },
        new {  _id = 4, title = "Book 4", pages = 50 },
      };
      Result r = ExecuteAddStatement(test.Add(docs));
      Assert.Equal(r.Warnings.Count, r.WarningsCount);

      var docResult = ExecuteFindStatement(test.Find());
      foreach (var doc in docResult)
      {
        var result = ExecuteAddStatement(test2.Add(doc));
        Assert.Equal<ulong>(1, result.AffectedItemsCount);
      }
    }
  }
}

==> mysql-connector-net-8.0.29-src.zip: MySQL.Data/tests/MySqlX.Data.Tests/CrudTests/DocBufferingTests.cs <==
// Copyright (c) 2015, 2020, Oracle and/or its affiliates. All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

using MySqlX.XDevAPI;
using MySqlX.XDevAPI.Common;
using NUnit.Framework;

namespace MySqlX.Data.Tests.CrudTests
{
  public class DocBufferingTests : BaseTest
  {
    [Test]
    public void SmartBuffering()
    {
      Collection test = CreateCollection("test");
      Collection test2 = CreateCollection("test2");

      var docs = new[]
      {
        new {  _id = 1, title = "Book 1", pages = 20 },
        new {  _id = 2, title = "Book 2", pages = 30 },
        new {  _id = 3, title = "Book 3", pages = 40 },
        new {  _id = 4, title = "Book 4", pages = 50 },
      };
      Result r = ExecuteAddStatement(test.Add(docs));
      Assert.AreEqual(r.Warnings.Count, r.WarningsCount);

      var docResult = ExecuteFindStatement(test.Find());
      foreach (var doc in docResult)
      {
        var result = ExecuteAddStatement(test2.Add(doc));
        Assert.AreEqual(1, result.AffectedItemsCount);
      }
    }
  }
}
